# Repoman

    A lot of people don't realize what's really going on.
    They view life as a bunch of unconnected incidents and things.
    They don't realize that there's this, like, lattice of
    coincidence that lays on top of everything.
     - Repo Man, 1984

Repoman is a collection of utilities for managing
individual software packages for the Fermi Gamma-Ray
Space telescope.

Documentation: https://fermi-lat.github.io/repoman/
